==> open-cluster-management-cluster-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterClaimSelectorFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorRequirement;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ClusterClaimSelectorFluent<A extends ClusterClaimSelectorFluent<A>> extends Fluent<A>{
  public A addToMatchExpressions(Integer index,LabelSelectorRequirement item);
  public A setToMatchExpressions(Integer index,LabelSelectorRequirement item);
  public A addToMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A addAllToMatchExpressions(Collection<LabelSelectorRequirement> items);
  public A removeFromMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A removeAllFromMatchExpressions(Collection<LabelSelectorRequirement> items);
  public List<LabelSelectorRequirement> getMatchExpressions();
  public LabelSelectorRequirement getMatchExpression(Integer index);
  public LabelSelectorRequirement getFirstMatchExpression();
  public LabelSelectorRequirement getLastMatchExpression();
  public LabelSelectorRequirement getMatchingMatchExpression(Predicate<LabelSelectorRequirement> predicate);
  public Boolean hasMatchingMatchExpression(Predicate<LabelSelectorRequirement> predicate);
  public A withMatchExpressions(List<LabelSelectorRequirement> matchExpressions);
  public A withMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... matchExpressions);
  public Boolean hasMatchExpressions();
  
}

==> open-cluster-management-cluster-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterClaimSelectorFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorRequirement;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ClusterClaimSelectorFluent<A extends ClusterClaimSelectorFluent<A>> extends Fluent<A>{
  public A addToMatchExpressions(int index,LabelSelectorRequirement item);
  public A setToMatchExpressions(int index,LabelSelectorRequirement item);
  public A addToMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A addAllToMatchExpressions(Collection<LabelSelectorRequirement> items);
  public A removeFromMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A removeAllFromMatchExpressions(Collection<LabelSelectorRequirement> items);
  public List<LabelSelectorRequirement> getMatchExpressions();
  public LabelSelectorRequirement getMatchExpression(int index);
  public LabelSelectorRequirement getFirstMatchExpression();
  public LabelSelectorRequirement getLastMatchExpression();
  public LabelSelectorRequirement getMatchingMatchExpression(Predicate<LabelSelectorRequirement> predicate);
  public Boolean hasMatchingMatchExpression(Predicate<LabelSelectorRequirement> predicate);
  public A withMatchExpressions(List<LabelSelectorRequirement> matchExpressions);
  public A withMatchExpressions(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... matchExpressions);
  public Boolean hasMatchExpressions();
  
}
